

% --------------------------------------------------------
% Equations for BPOP model
%       Elisa Lovecchio 2019 (e.lovecchio@exeter.ac.uk)
% --------------------------------------------------------


function dxdy = eqn_BPOP_LOOPzrem(t,var)

param_BPOP_LOOPzrem

% get vars

P_ss = var(1); P_ds = var(2); P_so = var(3); P_do = var(4);
P_shSed = var(5); P_ooSed = var(6);

O_ss = var(7); O_ds = var(8); O_so = var(9); O_do = var(10); 
O2frac_atmo = var(11); 

ij_idx = var(12); % passing a parameter that varies at each run to loop on the indeces (looping on the zrem ranges)

ispositive=(O2frac_atmo>0);

% --------------------------------------
%     Bio pump details

[ilarge,ismall] =  ind2sub([21,21],ij_idx);

zrem_small_sh = zrem_small_min+(ismall-1)*dsmall;
zrem_small_oo = zrem_small_min+(ismall-1)*dsmall;
    
zrem_large_sh = zrem_large_min+(ilarge-1)*dlarge;
zrem_large_oo = zrem_large_min+(ilarge-1)*dlarge;
    
coag_rate_eff = coag_rate;



% --------------------------------------
% 1. surface shelf (ss)

P_riv_sh =  P_riv_in/V_ss*(1-P_frac_so);

P_adv_mix_ss = (Upw*(P_ds-P_ss)+SS_mix*(P_so-P_ss)+VS_mix*(P_ds-P_ss))/V_ss;

prod_ss = P_up_max * (P_ss/(P_ss+Ks_P)) * P_ss; % Michaelis-Menten for P          

coag_ss = prod_ss^2 * coag_rate_eff; % all production is assumed to be small Porg initially  
small_POP_ss = prod_ss - coag_ss; 
large_POP_ss = coag_ss;
latexp_ss = small_POP_ss * LatFlx_ss/V_ss;
              % Ekman/lateral transport redistributes offshore part of the small Porg BEFORE export/remineralization
small_POP_ss = small_POP_ss - latexp_ss; 
exp_shelf_small = small_POP_ss * exp(-(DeltaZ_eu/2)/zrem_small_sh);
exp_shelf_large = large_POP_ss * exp(-(DeltaZ_eu/2)/zrem_large_sh);
exp_shelf_small = exp_shelf_small + small_POP_ss * VS_mix/V_ss;
exp_shelf_large = exp_shelf_large + large_POP_ss * VS_mix/V_ss;
exp_shelf = exp_shelf_large + exp_shelf_small;

dP_ss = P_riv_sh + P_adv_mix_ss - exp_shelf;

% --

O_adv_mix_ss = (Upw*(O_ds-O_ss)+SS_mix*(O_so-O_ss)+VS_mix*(O_ds-O_ss))/V_ss;

O_prod_ss = OP_redf * exp_shelf;

O_airsea_ss_mmolyr = K_w_myr * (O2frac_atmo/K_Henri - O_ss) * Area_shelf;
O_airsea_ss = O_airsea_ss_mmolyr / V_ss;

dO_ss = O_adv_mix_ss + O_prod_ss + O_airsea_ss;


% --------------------------------------
% 2. deep shelf (ds)

P_adv_mix_ds = (Upw*(P_do-P_ds)+DS_mix*(P_do-P_ds)+VS_mix*(P_ss-P_ds))/V_ds;

coag_ds = (exp_shelf_small*(V_ss/V_ds))^2 * coag_rate_eff; % coagulation of SPorg at depth 
new_smallpart_ds = exp_shelf_small*(V_ss/V_ds) - coag_ds;
new_largepart_ds = exp_shelf_large*(V_ss/V_ds) + coag_ds;
latexp_ds = new_smallpart_ds * LatFlx_ds/V_ds;
new_smallpart_ds = new_smallpart_ds - latexp_ds;
f_burial_small_ds = exp(-DeltaZ_ds/zrem_small_sh);
f_burial_large_ds = exp(-DeltaZ_ds/zrem_large_sh);
remin_shelf_small = new_smallpart_ds * (1-f_burial_small_ds);
remin_shelf_large = new_largepart_ds * (1-f_burial_large_ds);
remin_shelf = remin_shelf_small + remin_shelf_large;

MM_O2_ds = O_ds / (O_ds+K_O2); 
remin_sedim_shelf = max_remin_rate * MM_O2_ds * P_shSed/DeltaZ_ds;

dP_ds = P_adv_mix_ds + remin_shelf + remin_sedim_shelf;

% --

O_adv_mix_ds = (Upw*(O_do-O_ds)+DS_mix*(O_do-O_ds)+VS_mix*(O_ss-O_ds))/V_ds;

Osink_remin_ds = MM_O2_ds * (remin_shelf * OP_redf); 
Anaer_remin_ds = (1-MM_O2_ds) * (remin_shelf * OP_redf); % anaerobic respiration (product bubbles up to atmosphere)

Osink_sedim_shelf = remin_sedim_shelf * OP_redf;

dO_ds = O_adv_mix_ds - Osink_remin_ds - Osink_sedim_shelf;




% --------------------------------------
% 3. surface open ocean (so)

P_riv_so =  P_riv_in/V_so*P_frac_so;

P_adv_mix_so = (Upw*(P_ss-P_so)+SS_mix*(P_ss-P_so)+Mix*(P_do-P_so))/V_so;

prod_so = P_up_max * (P_so/(P_so+Ks_P)) * P_so;
latimp_small_so = latexp_ss * V_ss/V_so; % small Porg imported from coastal box
coag_so = (prod_so+latimp_small_so)^2 * coag_rate_eff; 
small_POP_so = (prod_so+latimp_small_so) - coag_so;
large_POP_so = coag_so;
exp_so_small = small_POP_so * exp(-(DeltaZ_eu/2)/zrem_small_oo); 
exp_so_large = large_POP_so * exp(-(DeltaZ_eu/2)/zrem_large_oo);
exp_so_small = exp_so_small + small_POP_so * Mix/V_so; 
exp_so_large = exp_so_large + large_POP_so * Mix/V_so;
exp_so = exp_so_large + exp_so_small;

dP_so = P_riv_so + P_adv_mix_so - exp_so;

% --

O_adv_mix_so = (Upw*(O_ss-O_so)+SS_mix*(O_ss-O_so)+Mix*(O_do-O_so))/V_so;

O_prod_so = OP_redf * exp_so;

O_airsea_so_mmolyr = K_w_myr * (O2frac_atmo/K_Henri - O_so) * Area_openo; 
O_airsea_so = O_airsea_so_mmolyr / V_so;

dO_so = O_adv_mix_so + O_prod_so + O_airsea_so;


% --------------------------------------
% 4. deep open ocean (do)

P_adv_mix_do = (Upw*(P_so-P_do)+Mix*(P_so-P_do)+DS_mix*(P_ds-P_do))/V_do;

latimp_small_do = latexp_ds * (V_ds/V_do);
coag_do = ((exp_so_small*(V_so/V_do)+latimp_small_do))^2 * coag_rate_eff; 
new_smallpart_do = (exp_so_small*(V_so/V_do)+latimp_small_do) - coag_do;
new_largepart_do = exp_so_large*(V_so/V_do) + coag_do;
f_burial_small_do = exp(-DeltaZ_do/zrem_small_oo); 
f_burial_large_do = exp(-DeltaZ_do/zrem_large_oo); 
remin_open_small = new_smallpart_do * (1-f_burial_small_do);
remin_open_large = new_largepart_do * (1-f_burial_large_do);
remin_open = remin_open_small + remin_open_large;

MM_O2_do = O_do / (O_do+K_O2);
remin_sedim_open = max_remin_rate * MM_O2_do * P_ooSed/DeltaZ_do;

dP_do = P_adv_mix_do + remin_open + remin_sedim_open;

% --

O_adv_mix_do = (Upw*(O_so-O_do)+Mix*(O_so-O_do)+DS_mix*(O_ds-O_do))/V_do;

Osink_remin_do = MM_O2_do * (remin_open * OP_redf);
Anaer_remin_do = (1-MM_O2_do) * (remin_open * OP_redf);

Osink_sedim_open = remin_sedim_open * OP_redf;

dO_do = O_adv_mix_do - Osink_remin_do - Osink_sedim_open;


% --------------------------------------
% 5. atmosphere (do)
                      %
O_airsea_ss_atmo = O_airsea_ss_mmolyr/mmol_atmo; 
O_airsea_so_atmo = O_airsea_so_mmolyr/mmol_atmo;

AnaerReact = (Anaer_remin_ds*V_ds + Anaer_remin_do*V_do)/mmol_atmo;

OxyWeath = Wox0_mmol * sqrt(O2frac_atmo*ispositive/O2mix_now)/mmol_atmo;

dpO2_atmo = - O_airsea_ss_atmo - O_airsea_so_atmo - OxyWeath - AnaerReact;  



% --------------------------------------
% 6. Sediments (Organic P reservoir, smallly remineralizaed)

burial_shelf_small = new_smallpart_ds * f_burial_small_ds;
burial_shelf_large = new_largepart_ds * f_burial_large_ds;
burial_shelf = (burial_shelf_small + burial_shelf_large) * DeltaZ_ds;

CaP_form_ds = P_shSed^2 * CaP_rate_mmol;
CaP_shelf = CaP_form_ds;

dP_shSed = burial_shelf - CaP_shelf - remin_sedim_shelf*DeltaZ_ds; 

% - 

burial_open_small = new_smallpart_do * f_burial_small_do;
burial_open_large = new_largepart_do * f_burial_large_do;
burial_open = (burial_open_small + burial_open_large) * DeltaZ_do;

CaP_form_do = P_ooSed^2 * CaP_rate_mmol;
CaP_open = CaP_form_do;

dP_ooSed = burial_open - CaP_open - remin_sedim_open*DeltaZ_do; 


% =======================================


dxdy=[dP_ss; dP_ds; dP_so; dP_do; dP_shSed; dP_ooSed; ...
           dO_ss; dO_ds; dO_so; dO_do; dpO2_atmo; 0];

end



