
% --------------------------------------------------------
% Run call for BPOP model [4 ocean + 1 atmo + 2 sediment boxes] 
%       Elisa Lovecchio 2019 (e.lovecchio@exeter.ac.uk)
% --------------------------------------------------------


clc

param_BPOP_LOOPzrem

% --- set folders and flags ---

output_dir='C:\Some_directory\'; % set here path where to save model's output


final_vars = zeros(13,441);  
final_flxs = zeros(18,441);
final_flxsByP = zeros(18,441);

var_names = {'z_{rem} SMALL [m]','z_{rem} LARGE [m]',...
    'P_{ss} [mmol/m^3]','P_{ds} [mmol/m^3]','P_{so} [mmol/m^3]','P_{do} [mmol/m^3]',...
    'Porg_{seds} [mmol/m^3]','Porg_{sedo} [mmol/m^3]',...
    'O_{ss} [mmol/m^3]','O_{ds} [mmol/m^3]','O_{so} [mmol/m^3]','O_{do} [mmol/m^3]',...
    'O_{atmo} [mmol/m^3]'};

flx_names = {'z_{rem} SMALL [m]','z_{rem} LARGE [m]',...
    'Prod_{shelf} [TmolP/yr]','Prod_{open} [TmolP/yr]','Exp_{shelf} [TmolP/yr]','Exp_{open} [TmolP/yr]',...
    'SedAcc_{shelf} [TmolP/yr]','SedAcc_{open} [TmolP/yr]','Bur_{shelf} [mmol/m^3]','Bur_{open} [mmol/m^3]',...
    'coag_{ss} [%]','coag_{ds} [%]','coag_{so} [%]','coag_{do} [%]',...
    'RemWat_{shelf} [TmolP/yr]','RemWat_{open} [TmolP/yr]','RemSed_{shelf} [mmol/m^3]','RemSed_{open} [mmol/m^3]'};
  
flxbyP_names = {'z_{rem} SMALL [m]','z_{rem} LARGE [m]',...
    'ProdSmall_{shelf} [TmolP/yr]','ProdLarge_{shelf} [TmolP/yr]','ProdSmall_{open} [TmolP/yr]','ProdLarge_{open} [TmolP/yr]',...
    'ExpSmall_{shelf} [TmolP/yr]','ExpLarge_{shelf} [TmolP/yr]','ExpSmall_{open} [TmolP/yr]','ExpLarge_{open} [TmolP/yr]',...
    'PdepthSmall_{shelf} [TmolP/yr]','PdepthLarge_{shelf} [TmolP/yr]','PdepthSmall_{open} [TmolP/yr]','PdepthLarge_{open} [TmolP/yr]',...
    'SedAccSmall_{shelf} [TmolP/yr]','SedAccLarge_{shelf} [TmolP/yr]','SedAccSmall_{open} [TmolP/yr]','SedAccLarge_{open} [TmolP/yr]'};
  
  
  
  
  

%% runs cycle


for ismall=1:21
    for ilarge=1:21
    
    % calculate coag speeds
    
    zrem_small_sh = zrem_small_min+(ismall-1)*dsmall;
    zrem_small_oo = zrem_small_min+(ismall-1)*dsmall;
    
    zrem_large_sh = zrem_large_min+(ilarge-1)*dlarge;
    zrem_large_oo = zrem_large_min+(ilarge-1)*dlarge;
    
    coag_rate_eff = coag_rate;
    
    ij_idx=sub2ind([21,21],ilarge,ismall);
    
    
    
    final_vars(1,ij_idx)=zrem_small_sh;
    final_vars(2,ij_idx)=zrem_large_sh;
    final_flxs(1,ij_idx)=zrem_small_sh;
    final_flxs(2,ij_idx)=zrem_large_sh;
    final_flxsByP(1,ij_idx)=zrem_small_sh;
    final_flxsByP(2,ij_idx)=zrem_large_sh;
    
    
    disp('==============================================================')
    disp(['Running ',runtitle,' - zrem params: zremS = ',num2str(zrem_small_sh),...
                          ' m, zremL = ',num2str(zrem_large_sh),'m'])
    
    % initialization
    P_ss_ini = PO4_ini;
    P_ds_ini = PO4_ini;
    P_so_ini = PO4_ini;
    P_do_ini = PO4_ini;
    
    P_shSed_ini = 0; % Porg in the sediments
    P_ooSed_ini = 0; % Porg in the sediments
    
    O_ss_ini = O2_ini;  
    O_ds_ini = O2_ini;  
    O_so_ini = O2_ini;
    O_do_ini = O2_ini;
    
    pO2_atmo_ini = O2_ini;
    ij=ij_idx;
    
    
    % define input vectors
    tspan=[0,t_simu];
    y0=[P_ss_ini,P_ds_ini,P_so_ini,P_do_ini,P_shSed_ini,P_ooSed_ini,...
        O_ss_ini,O_ds_ini,O_so_ini,O_do_ini,pO2_atmo_ini,ij];
    
    
    tic;
    
    % integrate
    [t,y]=ode15s(@(t,y) eqn_BPOP_LOOPzrem(t,y),tspan,y0);
    
    toc;
    disp(['TIMER: It took ', num2str(toc/60),' min to integrate ',num2str(t_simu/1e6),' Myr.'])
    
    
    
    % output
    P_ss=y(:,1);
    P_ds=y(:,2);
    P_so=y(:,3);
    P_do=y(:,4);
    
    P_shSed=y(:,5);
    P_ooSed=y(:,6);
    
    O_ss=y(:,7);
    O_ds=y(:,8);
    O_so=y(:,9);
    O_do=y(:,10);
    
    O2frac_atmo=y(:,11);

   
    
    % ====================================================================
    % Final values

    final_vars(3,ij_idx)=P_ss(end);
    final_vars(4,ij_idx)=P_ds(end);
    final_vars(5,ij_idx)=P_so(end);
    final_vars(6,ij_idx)=P_do(end);
    
    final_vars(7,ij_idx)=P_shSed(end);
    final_vars(8,ij_idx)=P_ooSed(end);
    
    final_vars(9,ij_idx)=O_ss(end);
    final_vars(10,ij_idx)=O_ds(end);
    final_vars(11,ij_idx)=O_so(end);
    final_vars(12,ij_idx)=O_do(end);
    
    final_vars(13,ij_idx)=O2frac_atmo(end); % oxygen molar fraction in atmosphere    
    
    

    
    % ====================================================================
    % Fluxes checks
    % =================================
    
    prod_ss = P_up_max * P_ss(end) * (P_ss(end)/(P_ss(end)+Ks_P)); 
    prod_so = P_up_max * P_so(end) * (P_so(end)/(P_so(end)+Ks_P)); 
    
    prod_tot = prod_ss * V_ss + prod_so * V_so;
    final_flxs(3,ij_idx)=prod_ss * V_ss/1e12*1e-3;
    final_flxs(4,ij_idx)=prod_so * V_so/1e12*1e-3;
    
    
    coag_ss = prod_ss^2 * coag_rate_eff; 
    small_POP_ss = prod_ss - coag_ss;
    large_POP_ss = coag_ss;
    
    latexp_ss = small_POP_ss * LatFlx_ss/V_ss;
    %prod_ss = prod_ss - latexp_ss;
    small_POP_ss = small_POP_ss - latexp_ss;
    exp_shelf_small = small_POP_ss * exp(-(DeltaZ_eu/2)/zrem_small_sh);
    exp_shelf_large = large_POP_ss * exp(-(DeltaZ_eu/2)/zrem_large_sh); 
    exp_shelf_small = exp_shelf_small + exp_shelf_small * VS_mix/V_ss; 
    exp_shelf_large = exp_shelf_large + exp_shelf_large * VS_mix/V_ss;
    exp_shelf = exp_shelf_large + exp_shelf_small;
    

    latimp_small = latexp_ss * V_ss/V_so; 
    coag_so = (prod_so+latimp_small)^2 * coag_rate_eff; 
    small_POP_so = (prod_so+latimp_small) - coag_so;
    large_POP_so = coag_so;
    exp_so_small = small_POP_so * exp(-(DeltaZ_eu/2)/zrem_small_oo);
    exp_so_large = large_POP_so * exp(-(DeltaZ_eu/2)/zrem_large_oo);
    exp_so_small = exp_so_small + small_POP_so * Mix/V_so;
    exp_so_large = exp_so_large + large_POP_so * Mix/V_so;
    exp_so = exp_so_large + exp_so_small;
    
    exp_tot = exp_shelf * V_ss + exp_so * V_so;
    
    final_flxs(5,ij_idx)=exp_shelf * V_ss/1e12*1e-3;
    final_flxs(6,ij_idx)=exp_so * V_so/1e12*1e-3;
    
    final_flxsByP(3,ij_idx)=small_POP_ss;
    final_flxsByP(4,ij_idx)=large_POP_ss;
    final_flxsByP(5,ij_idx)=small_POP_so;
    final_flxsByP(6,ij_idx)=large_POP_so;
    
    final_flxsByP(7,ij_idx)=exp_shelf_small;
    final_flxsByP(8,ij_idx)=exp_shelf_large;
    final_flxsByP(9,ij_idx)=exp_so_small;
    final_flxsByP(10,ij_idx)=exp_so_large;
    
    
    coag_ds = (exp_shelf_small*(V_ss/V_ds))^2 * coag_rate_eff; 
    new_smallpart_ds = (exp_shelf_small*(V_ss/V_ds)) - coag_ds;
    new_largepart_ds = exp_shelf_large + coag_ds;
    latexp_ds = new_smallpart_ds * LatFlx_ds/V_ds;
    new_smallpart_ds = new_smallpart_ds - latexp_ds;
    f_burial_small_ds = exp(-DeltaZ_ds/zrem_small_sh);
    f_burial_large_ds = exp(-DeltaZ_ds/zrem_large_sh); 
    remin_shelf_small = new_smallpart_ds * (V_ss/V_ds) * (1-f_burial_small_ds);
    remin_shelf_large = new_largepart_ds * (V_ss/V_ds) * (1-f_burial_large_ds);
    remin_shelf = remin_shelf_small + remin_shelf_large;
    MM_O2_ds = O_ds(end) / (O_ds(end)+K_O2); 
    remin_sedim_shelf = max_remin_rate * MM_O2_ds * P_shSed(end)/DeltaZ_ds;
    
    latimp_small_do = latexp_ds * (V_ds/V_do);
    coag_do = ((exp_so_small*(V_so/V_do)+latimp_small_do))^2 * coag_rate_eff; 
    new_smallpart_do = exp_so_small*(V_so/V_do) + latimp_small_do - coag_do;
    new_largepart_do = exp_so_large*(V_so/V_do) + coag_do;
    f_burial_small_do = exp(-DeltaZ_do/zrem_small_oo); 
    f_burial_large_do = exp(-DeltaZ_do/zrem_large_oo); 
    remin_open_small = new_smallpart_do * (1-f_burial_small_do);
    remin_open_large = new_largepart_do * (1-f_burial_large_do);
    remin_open = remin_open_small + remin_open_large;
    MM_O2_do = O_do(end) / (O_do(end)+K_O2); 
    remin_sedim_open = max_remin_rate * MM_O2_do * P_ooSed(end)/DeltaZ_do;

    final_flxsByP(11,ij_idx)=new_smallpart_ds;
    final_flxsByP(12,ij_idx)=new_largepart_ds;
    final_flxsByP(13,ij_idx)=new_smallpart_do;
    final_flxsByP(14,ij_idx)=new_largepart_do;
    
    
    burial_shelf_small = new_smallpart_ds * f_burial_small_ds;
    burial_shelf_large = new_largepart_ds * f_burial_large_ds;
    burial_shelf = (burial_shelf_small + burial_shelf_large) * DeltaZ_ds;
    
    CaP_form_ds = P_shSed(end)^2 * CaP_rate_mmol;
    CaP_shelf = CaP_form_ds;
    
    burial_open_small = new_smallpart_do * f_burial_small_do;
    burial_open_large = new_largepart_do * f_burial_large_do;
    burial_open = (burial_open_small + burial_open_large) * DeltaZ_do;
    
    CaP_form_do = P_ooSed(end) ^2 * CaP_rate_mmol;
    CaP_open = CaP_form_do;
    
    actual_burial = CaP_shelf * Area_shelf + CaP_open * Area_openo;
    
    sedim_accum = burial_shelf * Area_shelf + burial_open * Area_openo;
    sedim_accum_perA = (burial_shelf * Area_shelf + burial_open * Area_openo)/(Area_shelf + Area_openo);
    
    final_flxs(7,ij_idx)= burial_shelf * Area_shelf/1e12*1e-3; 
    final_flxs(8,ij_idx)= burial_open * Area_openo/1e12*1e-3;
    final_flxs(9,ij_idx)= CaP_shelf * Area_shelf/1e12*1e-3; 
    final_flxs(10,ij_idx)= CaP_open * Area_openo/1e12*1e-3;
    
    final_flxsByP(15,ij_idx)=burial_shelf_small;
    final_flxsByP(16,ij_idx)=burial_shelf_large;
    final_flxsByP(17,ij_idx)=burial_open_small;
    final_flxsByP(18,ij_idx)=burial_open_large;
    
    
    O_airsea_ss_mmolyrm2 = K_w_myr * (O2frac_atmo(end)/K_Henri - O_ss(end));
    O_airsea_so_mmolyrm2 = K_w_myr * (O2frac_atmo(end)/K_Henri - O_so(end));
    
    final_flxs(11,ij_idx) = max(0,coag_ss/prod_ss*100);
    final_flxs(12,ij_idx) = max(0,coag_ds/(exp_shelf_small*(V_ss/V_ds))*100);
    final_flxs(13,ij_idx) = max(0,coag_so/(prod_so+latimp_small)*100);
    final_flxs(14,ij_idx) = max(0,coag_do/(exp_so_small*(V_so/V_do)+latimp_small_do)*100);
    
    final_flxs(15,ij_idx) = remin_shelf * V_ds/1e12*1e-3;
    final_flxs(16,ij_idx) = remin_open * V_do/1e12*1e-3;
    final_flxs(17,ij_idx) = remin_sedim_shelf * V_ds/1e12*1e-3;
    final_flxs(18,ij_idx) = remin_sedim_open * V_do/1e12*1e-3;
    
    
    disp('   ')
    
    end
end


save([output_dir,runtitle,'_data'],'final_vars','var_names','final_flxs','flx_names','final_flxsByP','flxbyP_names');

%diary off














